# Fan Control for QNAP TS-464 on UnRAID

This guide provides instructions on how to control the fan on a QNAP TS-464 running UnRAID using the QNAP-EC Plugin.

## Prerequisites

- UnRAID server up and running
- SSH access to your UnRAID server
- Basic understanding of command-line operations

## Table of Contents

1. [Install QNAP-EC Plugin](#step-1-install-qnap-ec-plugin)
2. [Load the Kernel Module](#step-2-load-the-kernel-module)
3. [Verify Fan Reporting](#step-3-verify-fan-reporting)
4. [Identify hwmon Directory](#step-4-identify-hwmon-directory)
5. [Control the Fan](#step-5-control-the-fan)
6. [Troubleshooting](#troubleshooting)

## Step 1: Install QNAP-EC Plugin

You have two options to install the QNAP-EC Plugin:

1. **Through UnRAID WebUI**: Navigate to the 'Plugins' tab and use the built-in plugin installation features.
2. **Manual Installation**: 
    - Visit the [GitHub repository for QNAP-EC Plugin](https://github.com/ich777/unraid-qnapec).
    - Grab the URL of the `qnap-ec.plg` file.
    - In your UnRAID WebUI, go to the 'Plugins' tab.
    - Paste the URL into the 'Install Plugin' section and click 'Install'.

## Step 2: Load the Kernel Module

SSH into your UnRAID server and execute the following command:

```bash
mkdir -p /boot/config/modprobe.d
echo "options qnap-ec check-for-chip=no" > /boot/config/modprobe.d/qnap-ec.config
modprobe qnap-ec check-for-chip=no
```
This will create a file on the boot drive so that you don't have to load the driver manually on next reboot with the option `check-for-chip=no` and finally load the QNAP-EC kernel module and skip the chip presence check for the existing session.

## Step 3: Verify Fan Reporting
Check to see if the fans are being correctly reported on your UnRAID dashboard. If it's correctly set up, you should see the fan speed under the hardware status. You might see two other fans that are unrelated. I'd just ignore them as they seem to be harmless.

## Step 4: Identify hwmon Directory
SSH into your UnRAID server and navigate to /sys/class/hwmon/:

```bash
cd /sys/class/hwmon/
ls -la
```

Look for the symlink that points to ../../devices/platform/qnap-ec/hwmon/hwmonX/. The X will be a number, for example, hwmon4.

## Step 5: Control the Fan
Navigate to the identified hwmon directory:
`cd /sys/class/hwmon/hwmonX/`

List the directory contents to identify the PWM entries (pwm1, pwm2, etc.):
In my case, pwm1 was the fan inside of the TS-464. 

To set the fan speed, run `echo VALUE > pwm1`, replacing 'VALUE' with a number between 0 and 255. 0 is for minimum speed, and 255 is for maximum speed.

## Troubleshooting
If you see extra fans reported, it's likely due to how the hardware monitoring chips are programmed. This is generally harmless and can be ignored.

Ensure that you replace hwmonX and VALUE in the commands with the actual directory and speed value, respectively.
